pyxmpp2.stanzapayload

Package pyxmpp2 :: Module stanzapayload |
[hide private]

# Module stanzapayload

XMPP payload classes.

Classes | [hide private]
| XMLPayload Transparent XML payload for stanza.

Functions | [hide private]
payload_class_for_element_name(element_name) Return a payload class for given element name. |
payload_element_names_for_class(klass) Return a payload element name for given class. |
payload_factory(element) Return a specialized StanzaPayload object for given element. |

Variables | [hide private]
| STANZA_PAYLOAD_CLASSES = ``{``u'``{urn:ietf:params:xml:ns:xmpp-bind}``...``
| STANZA_PAYLOAD_ELEMENTS = `defaultdict(<type 'list'>, {<class '`...``
| logger = `logging.getLogger("pyxmpp.stanzapayload")`

Variables Details | [hide private]

  ### STANZA_PAYLOAD_CLASSES Value:
      {u'{urn:ietf:params:xml:ns:xmpp-bind}bind': <class 'pyxmpp2.binding.Re
      sourceBindingPayload'>}

  ### STANZA_PAYLOAD_ELEMENTS Value:
      defaultdict(<type 'list'>, {<class 'pyxmpp2.binding.ResourceBindingPay
      load'>: [u'{urn:ietf:params:xml:ns:xmpp-bind}bind']})